function [ Anew ] = dalec_EnKF_analysis( A, H, params, obs, obsLut )
%DALEC_ENKF_ANALYSIS analysis step of the EnKF

nObs=length(obs);

nrmin=min( nObs, params.nrens );

sigsum1=0.;
nrsigma=0.;

%allocate matrices
Anew=zeros(size(A));

%compute HA
HA=H*A;

%compute mean HA
HA_mean=mean(HA,2);

%generate E (measurement peturbations) 
%and D (perturbed obs)

E=zeros(nObs, params.nrens);
D=zeros(nObs, params.nrens);

for i=1:nObs;
    if params.obserrtype(obsLut(i))==0;
        E(i,:)=randn(params.nrens,1)*sqrt(params.obserrstd(obsLut(i)));
        D(i,:)=E(i,:)+obs(i);
    else
        E(i,:)=randn(params.nrens,1)*sqrt(params.obserrstd(obsLut(i)))*obs(i);
        D(i,:)=E(i,:)+obs(i);
    end
end


%compute D' where D'=D-HA
D_dash=D-HA;

%compute S where S=HA-HA_mean
S=zeros(size(HA));
for i=1:params.nrens;
    S(:,i)=HA(:,i)-HA_mean;
end
    
ES=E+S;


%SVD
%note - reason why SVD is called twice is to avoid 
% singular being returned as a matrix - problem is that
%it is sometimes a vector and sometimes a matrix, which 
%results in problems for the matlab "diag" command 
%(which works differently on matrices and vectors)

[U,~,V]=svd(ES);
singular=svd(ES);

sig=power(singular,2);
sigsum=sum(sig);


%compute no. significant eigenvalues 
for i=1:nrmin;
    if sigsum1/sigsum < 0.999;
        nrsigma=nrsigma+1;
        sigsum1=sigsum1+sig(i);
        sig(i)=1.0/sig(i);
    else
        for j=i:nrmin;
            sig(j)=0;
        end
        break;
    end
end


%X1
X1=zeros(nrmin,nObs);
for j=1:nObs;
    for i=1:nrmin;
        X1(i,j)=sig(i)*U(j,i);
    end
end

X2=X1*D_dash;
X3=U*X2;

X4=S'*X3+eye(params.nrens);
Anew=A*X4;

%INCORRECT - do NOT uncomment:
%Reps=A*S';
%A_new=Reps*X3+A;

end
