function [ params ] = dalec_initParams( )
%DALEC_INITPARAMS initialise the DALEC parameters
%   Default dalec parameters and model set up
%   are returned in a structure from this function.
%   These can be changed afterward (e.g. by reading
%   from a GUI).


%number of ensembles, dimensions etc
params.nrens=200;
params.ndims=16;
params.maxObs=11;

params.missingFlag=-9999;
%params.daType='enkf';

%misc parameters

params.lat=42.0*pi/180. ;

% state vector positions (do not change)
params.DALEC_POS_RA=uint8(1);
params.DALEC_POS_AF=uint8(2);
params.DALEC_POS_AW=uint8(3);
params.DALEC_POS_AR=uint8(4);
params.DALEC_POS_LF=uint8(5);
params.DALEC_POS_LW=uint8(6);
params.DALEC_POS_LR=uint8(7);
params.DALEC_POS_CF=uint8(8);
params.DALEC_POS_CW=uint8(9);
params.DALEC_POS_CR=uint8(10);
params.DALEC_POS_RH1=uint8(11);
params.DALEC_POS_RH2=uint8(12);
params.DALEC_POS_D=uint8(13);
params.DALEC_POS_CL=uint8(14);
params.DALEC_POS_CS=uint8(15);
params.DALEC_POS_GPP=uint8(16);


%parameter values
params.T1=4.41E-06; %/*t1 - Decomposition from litter to SOM*/
params.T2=0.473267; %/*t2 - % GPP lost to respiration */
params.T3=0.314951; %/*t3 - % NPP sent to foliage */
params.T4=0.434401; %/*t4 - % NPP sent to roots */
params.T5=0.00266518; %/*t5 - rate of leaf loss*/
params.T6=2.06E-06; %/*t6 - rate of wood loss*/
params.T7=2.48E-03; %/*t7 - rate of root loss*/
params.T8=2.28E-02; %/*t8 - rate of respiration from litter*/
params.T9=2.65E-06; %/*t9 - rate of respiration from litter SOM*/
params.CF0=57.7049; %/*Cf*/
params.CW0=769.863; %/*Cw*/
params.CR0=101.955; %/*Cr*/
params.CL0=40.4494; %/*Clit*/
params.CS0=9896.7; %/*Csom*/

params.SLA=1./111.0;

%acm parameters
params.ACM_P1=2.155 ;
params.ACM_P2=0.01416 ;
params.ACM_P3=217.9 ;
params.ACM_P4=0.9804 ;
params.ACM_P5=0.1548 ;
params.ACM_P6=2.653 ;
params.ACM_P7=4.309 ;
params.ACM_P8=0.06013 ;
params.ACM_P9=1.062 ;
params.ACM_P10=0.0006575 ;


%error variances
params.errvar(params.DALEC_POS_RA)=0.2; 
params.errvar(params.DALEC_POS_AF)=0.2; 
params.errvar(params.DALEC_POS_AW)=0.2; 
params.errvar(params.DALEC_POS_AR)=0.2; 
params.errvar(params.DALEC_POS_LF)=0.5; 
params.errvar(params.DALEC_POS_LW)=0.5; 
params.errvar(params.DALEC_POS_LR)=0.5; 
params.errvar(params.DALEC_POS_CF)=0.2; 
params.errvar(params.DALEC_POS_CW)=0.2; 
params.errvar(params.DALEC_POS_CR)=0.2; 
params.errvar(params.DALEC_POS_RH1)=0.2; 
params.errvar(params.DALEC_POS_RH2)=0.2; 
params.errvar(params.DALEC_POS_D)=0.2; 
params.errvar(params.DALEC_POS_CL)=0.2; 
params.errvar(params.DALEC_POS_CS)=0.2; 
params.errvar(params.DALEC_POS_GPP)=0.2; 

%error types
%0 indicates that the error 
%variance is absolute and 
%1 indicates that it is relative to the magnitude of 
%the state vector element 

params.errtype(params.DALEC_POS_RA)=uint8(1); 
params.errtype(params.DALEC_POS_AF)=uint8(1); 
params.errtype(params.DALEC_POS_AW)=uint8(1); 
params.errtype(params.DALEC_POS_AR)=uint8(1); 
params.errtype(params.DALEC_POS_LF)=uint8(0); 
params.errtype(params.DALEC_POS_LW)=uint8(0); 
params.errtype(params.DALEC_POS_LR)=uint8(0); 
params.errtype(params.DALEC_POS_CF)=uint8(1); 
params.errtype(params.DALEC_POS_CW)=uint8(1); 
params.errtype(params.DALEC_POS_CR)=uint8(1); 
params.errtype(params.DALEC_POS_RH1)=uint8(1); 
params.errtype(params.DALEC_POS_RH2)=uint8(1); 
params.errtype(params.DALEC_POS_D)=uint8(1); 
params.errtype(params.DALEC_POS_CL)=uint8(1); 
params.errtype(params.DALEC_POS_CS)=uint8(1); 
params.errtype(params.DALEC_POS_GPP)=uint8(1); 


%observation positions:
%(do not change - must correspond to the 
%order of columns in the input data)

params.OBS_POS_GPP=uint8(1);
params.OBS_POS_NEE=uint8(2);
params.OBS_POS_RT=uint8(3);
params.OBS_POS_RA=uint8(4);
params.OBS_POS_LF=uint8(5);
params.OBS_POS_LW=uint8(6);
params.OBS_POS_CF=uint8(7);
params.OBS_POS_CW=uint8(8);
params.OBS_POS_CL=uint8(9);
params.OBS_POS_CS=uint8(10);
params.OBS_POS_CR=uint8(11);


%observation errors (stdv):
params.obserrstd(params.OBS_POS_GPP)=0.3;
params.obserrstd(params.OBS_POS_NEE)=0.5;
params.obserrstd(params.OBS_POS_RT)=0.2;
params.obserrstd(params.OBS_POS_RA)=0.5;
params.obserrstd(params.OBS_POS_LF)=0.2;
params.obserrstd(params.OBS_POS_LW)=0.2;
params.obserrstd(params.OBS_POS_CF)=0.1;
params.obserrstd(params.OBS_POS_CW)=0.1;
params.obserrstd(params.OBS_POS_CL)=0.3;
params.obserrstd(params.OBS_POS_CS)=0.3;
params.obserrstd(params.OBS_POS_CR)=0.3;

%observation error types:
%0 indicates that the error 
%variance is absolute and 
%1 indicates that it is relative to the magnitude of 
%the observation
params.obserrtype(params.OBS_POS_GPP)=uint8(1);
params.obserrtype(params.OBS_POS_NEE)=uint8(0);
params.obserrtype(params.OBS_POS_RT)=uint8(1);
params.obserrtype(params.OBS_POS_RA)=uint8(1);
params.obserrtype(params.OBS_POS_LF)=uint8(1);
params.obserrtype(params.OBS_POS_LW)=uint8(1);
params.obserrtype(params.OBS_POS_CF)=uint8(1);
params.obserrtype(params.OBS_POS_CW)=uint8(1);
params.obserrtype(params.OBS_POS_CL)=uint8(1);
params.obserrtype(params.OBS_POS_CS)=uint8(1);
params.obserrtype(params.OBS_POS_CR)=uint8(1);



end

