function [ ensemble ] = dalec_propagate( ensemble, params, driversDay )
%DALEC_PROPAGATE move the dalec state vector on one time step

ensemble_new=zeros(size(ensemble));

for i=1:params.nrens,
    
    lai=ensemble(params.DALEC_POS_CF,i)*params.SLA;
    lai=max(0.1,lai);
    gpp=dalec_acm( lai, params, driversDay );
    
    ensemble_new(params.DALEC_POS_GPP,i)=gpp;
    ensemble_new(params.DALEC_POS_RA,i)=gpp*params.T2;
    ensemble_new(params.DALEC_POS_AF,i)=gpp*params.T3*(1.-params.T2);
    ensemble_new(params.DALEC_POS_AR,i)=gpp*params.T4*(1.-params.T2);
    ensemble_new(params.DALEC_POS_AW,i)=gpp*(1.-params.T3-params.T4 ) ...
        *(1.-params.T2);
    
    ensemble_new(params.DALEC_POS_LF,i)=ensemble(params.DALEC_POS_CF,i) ...
        *params.T5;
    ensemble_new(params.DALEC_POS_LW,i)=ensemble(params.DALEC_POS_CW,i) ...
        *params.T6;
    ensemble_new(params.DALEC_POS_LR,i)=ensemble(params.DALEC_POS_CR,i) ...
        *params.T7;
		
    ensemble_new(params.DALEC_POS_RH1,i)=driversDay.rate* ... 
        ensemble(params.DALEC_POS_CL,i)*params.T8;
    ensemble_new(params.DALEC_POS_RH2,i)=driversDay.rate* ...
        ensemble(params.DALEC_POS_CS,i)*params.T9;
    ensemble_new(params.DALEC_POS_D,i)=driversDay.rate* ...
        ensemble(params.DALEC_POS_CL,i)*params.T1;
    
    ensemble_new(params.DALEC_POS_CF,i)=ensemble(params.DALEC_POS_CF,i) ...
        +ensemble(params.DALEC_POS_AF,i)-ensemble(params.DALEC_POS_LF,i);
    
    ensemble_new(params.DALEC_POS_CW,i)=ensemble(params.DALEC_POS_CW,i) ...
        +ensemble(params.DALEC_POS_AW,i)-ensemble(params.DALEC_POS_LW,i);
    
    ensemble_new(params.DALEC_POS_CR,i)=ensemble(params.DALEC_POS_CR,i) ...
        +ensemble(params.DALEC_POS_AR,i)-ensemble(params.DALEC_POS_LR,i);
		
    ensemble_new(params.DALEC_POS_CL,i)=ensemble(params.DALEC_POS_CL,i) ...
        +ensemble(params.DALEC_POS_LF,i) ...
        +ensemble(params.DALEC_POS_LR,i) ...
        -ensemble(params.DALEC_POS_RH1,i) ...
        -ensemble(params.DALEC_POS_D,i);
		
    ensemble_new(params.DALEC_POS_CS,i)=ensemble(params.DALEC_POS_CS,i) ...
        +ensemble(params.DALEC_POS_D,i) ...
        +ensemble(params.DALEC_POS_LW,i) ...
        -ensemble(params.DALEC_POS_RH2,i);    
    
end

ensemble=ensemble_new;

end

