function [ ] = plotEnsembles( var, data, driverFileName, params )
%PLOTENSEMBLES Summary of this function goes here
%   Detailed explanation goes here

%include drivers?
if nargin<3
    driverFileName='none';
end

%initialise parameters (p) if not passed to the function
if nargin <4
    params=dalec_initParams();
else
    params=params;
end

var=upper(var);
obsPos=-1;

if strcmp(var,'GPP')
    obsPos=params.OBS_POS_GPP;
    varPos=params.DALEC_POS_GPP;
elseif strcmp(var,'NEE')
    obsPos=params.OBS_POS_NEE;
    varPos=-1;
elseif strcmp(var,'RT')
    obsPos=params.OBS_POS_RT;
    varPos=-2;
elseif strcmp(var,'RA')
    obsPos=params.OBS_POS_RA;
    varPos=params.DALEC_POS_RA;
elseif strcmp(var,'LF')
    obsPos=params.OBS_POS_LF;
    varPos=params.DALEC_POS_LF;
elseif strcmp(var,'LW')
    obsPos=params.OBS_POS_LW;
    varPos=params.DALEC_POS_LW;
elseif strcmp(var,'CF')
    obsPos=params.OBS_POS_CF;
    varPos=params.DALEC_POS_CF;
elseif strcmp(var,'CW')
    obsPos=params.OBS_POS_CW;
    varPos=params.DALEC_POS_CW;
elseif strcmp(var,'CL')
    obsPos=params.OBS_POS_CL;
    varPos=params.DALEC_POS_CL;
elseif strcmp(var,'CS')
    obsPos=params.OBS_POS_CS;
    varPos=params.DALEC_POS_CS;
elseif strcmp(var,'CR')
    obsPos=params.OBS_POS_CR;
    varPos=params.DALEC_POS_CR;
elseif strcmp(var,'RH1')
    varPos=params.DALEC_POS_RH1;
elseif strcmp(var,'RH2')
    varPos=params.DALEC_POS_RH2;
elseif strcmp(var,'LR')
    varPos=params.DALEC_POS_LR;
elseif strcmp(var,'AF')
    varPos=params.DALEC_POS_LR;
elseif strcmp(var,'AR')
    varPos=params.DALEC_POS_LR;
elseif strcmp(var,'AW')
    varPos=params.DALEC_POS_LR;
else
    error('Unknown variable type specified');
end

%reshape the data
[x,y,z]=size(data);

if varPos==-1 %NEE requested
    gpp=reshape(data(:,params.DALEC_POS_GPP,:),[x,z]);
    ra=reshape(data(:,params.DALEC_POS_RA,:),[x,z]);
    rh1=reshape(data(:,params.DALEC_POS_RH1,:),[x,z]);
    rh2=reshape(data(:,params.DALEC_POS_RH2,:),[x,z]);
    data=-gpp+ra+rh1+rh2;
elseif varPos==-2 %RT requested
    ra=reshape(data(:,params.DALEC_POS_RA,:),[x,z]);
    rh1=reshape(data(:,params.DALEC_POS_RH1,:),[x,z]);
    rh2=reshape(data(:,params.DALEC_POS_RH2,:),[x,z]);
    %shape(rh)
    data=rh1+rh2+ra;    
else
    data=reshape(data(:,varPos,:),[x,z]);  
end


X=[1:x];
Xfill=[X,fliplr(X)];
Dmean=mean(data,2);
Dmedian=median(data,2);
Dstdv=std(data,0,2) ;
Y1=Dmean+Dstdv;
Y2=Dmean-Dstdv;
Y=[Y1',fliplr(Y2')];
fill(Xfill,Y,[0.7,0.7,0.7],'EdgeColor','w');
hold on
plot(X,Dmean,'black');
plot(X,Dmedian,'black');
hold off

if obsPos > 0 && ~strcmp(driverFileName,'none')
    
    %read drivers (d) and observations (o)
    [d, o]=dalec_readDrivers(driverFileName);
    
    %strip missing obs
    o=o(:,obsPos);    
    X=X(o>-9999);
    o=o(o>-9999);
    
    %relative or absolute errors
    if params.obserrtype(obsPos)==1
        err=params.obserrstd(obsPos)*o;
    else
        err=params.obserrstd(obsPos)*ones(size(o));
    end
    
    %do the ploting - including error bars if there's not too much data
    %(otherwise you cant see the ensembles)
    hold on
    if length(o) < 100
      errorbar(X,o,err,'or','LineWidth',2);
    elseif length(o) < 500
      errorbar(X,o,err,'or','LineWidth',1);
    else
      plot(X,o,'or');    
    end
    
    hold off
end

end

